@@ -18,7 +18,9 @@ from cloudevents.http.event import CloudEvent
 from cloudevents.http.event_type import is_binary, is_structured
 from cloudevents.http.http_methods import (
     from_http,
+    to_binary,
     to_binary_http,
+    to_structured,
     to_structured_http,
 )
 from cloudevents.http.json_methods import from_json, to_json
